summaryrefslogtreecommitdiffstats
path: root/qtinterface/qt4/Qt/qglobal.h
diff options
context:
space:
mode:
Diffstat (limited to 'qtinterface/qt4/Qt/qglobal.h')
-rw-r--r--qtinterface/qt4/Qt/qglobal.h56
1 files changed, 28 insertions, 28 deletions
diff --git a/qtinterface/qt4/Qt/qglobal.h b/qtinterface/qt4/Qt/qglobal.h
index 9b647a9..7ab2b24 100644
--- a/qtinterface/qt4/Qt/qglobal.h
+++ b/qtinterface/qt4/Qt/qglobal.h
@@ -488,7 +488,7 @@ namespace QT_NAMESPACE {}
# if __GNUC__ < 3 || (__GNUC__ == 3 && __GNUC_MINOR__ <= 3)
# define Q_NO_TEMPLATE_FRIENDS
# endif
/* Apple's GCC 3.1 chokes on our streaming qDebug() */
# if defined(Q_OS_DARWIN) && __GNUC__ == 3 && (__GNUC_MINOR__ >= 1 && __GNUC_MINOR__ < 3)
# define Q_BROKEN_DEBUG_STREAM
# endif
@@ -1522,15 +1522,15 @@ public:
#endif
};
-Q_CORE_EXPORT const char *qVersion();
-Q_CORE_EXPORT bool qSharedBuild();
+Q_CORE_EXPORT const char *tqVersion();
+Q_CORE_EXPORT bool tqSharedBuild();
#if defined(Q_OS_MAC)
inline int qMacVersion() { return QSysInfo::MacintoshVersion; }
#endif
#ifdef QT3_SUPPORT
-inline QT3_SUPPORT bool qSysInfo(int *wordSize, bool *bigEndian)
+inline QT3_SUPPORT bool tqSysInfo(int *wordSize, bool *bigEndian)
{
*wordSize = QSysInfo::WordSize;
*bigEndian = (QSysInfo::ByteOrder == QSysInfo::BigEndian);
@@ -1593,13 +1593,13 @@ inline void qUnused(T &x) { (void)x; }
# define qPrintable(string) (string).toLocal8Bit().constData()
#endif
-Q_CORE_EXPORT void qDebug(const char *, ...) /* print debug message */
+Q_CORE_EXPORT void tqDebug(const char *, ...) /* print debug message */
#if defined(Q_CC_GNU) && !defined(__INSURE__)
__attribute__ ((format (printf, 1, 2)))
#endif
;
-Q_CORE_EXPORT void qWarning(const char *, ...) /* print warning message */
+Q_CORE_EXPORT void tqWarning(const char *, ...) /* print warning message */
#if defined(Q_CC_GNU) && !defined(__INSURE__)
__attribute__ ((format (printf, 1, 2)))
#endif
@@ -1612,14 +1612,14 @@ Q_CORE_EXPORT void qCritical(const char *, ...) /* print critical message */
__attribute__ ((format (printf, 1, 2)))
#endif
;
-Q_CORE_EXPORT void qFatal(const char *, ...) /* print fatal message and exit */
+Q_CORE_EXPORT void tqFatal(const char *, ...) /* print fatal message and exit */
#if defined(Q_CC_GNU) && !defined(__INSURE__)
__attribute__ ((format (printf, 1, 2)))
#endif
;
#ifdef QT3_SUPPORT
-Q_CORE_EXPORT QT3_SUPPORT void qSystemWarning(const char *msg, int code = -1);
+Q_CORE_EXPORT QT3_SUPPORT void tqSystemWarning(const char *msg, int code = -1);
#endif /* QT3_SUPPORT */
Q_CORE_EXPORT void qErrnoWarning(int code, const char *msg, ...);
Q_CORE_EXPORT void qErrnoWarning(const char *msg, ...);
@@ -1631,25 +1631,25 @@ Q_CORE_EXPORT void qErrnoWarning(const char *msg, ...);
/*
Forward declarations only.
- In order to use the qDebug() stream, you must #include<QDebug>
+ In order to use the tqDebug() stream, you must #include<QDebug>
*/
class QDebug;
class QNoDebug;
#ifndef QT_NO_DEBUG_STREAM
-Q_CORE_EXPORT_INLINE QDebug qDebug();
-Q_CORE_EXPORT_INLINE QDebug qWarning();
+Q_CORE_EXPORT_INLINE QDebug tqDebug();
+Q_CORE_EXPORT_INLINE QDebug tqWarning();
Q_CORE_EXPORT_INLINE QDebug qCritical();
#else
-inline QNoDebug qDebug();
+inline QNoDebug tqDebug();
#endif
-#define QT_NO_QDEBUG_MACRO while (false) qDebug
+#define QT_NO_QDEBUG_MACRO while (false) tqDebug
#ifdef QT_NO_DEBUG_OUTPUT
-# define qDebug QT_NO_QDEBUG_MACRO
+# define tqDebug QT_NO_QDEBUG_MACRO
#endif
-#define QT_NO_QWARNING_MACRO while (false) qWarning
+#define QT_NO_QWARNING_MACRO while (false) tqWarning
#ifdef QT_NO_WARNING_OUTPUT
-# define qWarning QT_NO_QWARNING_MACRO
+# define tqWarning QT_NO_QWARNING_MACRO
#endif
@@ -1731,8 +1731,8 @@ typedef void (*QtMsgHandler)(QtMsgType, const char *);
Q_CORE_EXPORT QtMsgHandler qInstallMsgHandler(QtMsgHandler);
#ifdef QT3_SUPPORT
-inline QT3_SUPPORT void qSuppressObsoleteWarnings(bool = true) {}
-inline QT3_SUPPORT void qObsolete(const char *, const char * = 0, const char * = 0) {}
+inline QT3_SUPPORT void tqSuppressObsoleteWarnings(bool = true) {}
+inline QT3_SUPPORT void tqObsolete(const char *, const char * = 0, const char * = 0) {}
#endif
#if defined(QT_NO_THREAD)
@@ -1941,7 +1941,7 @@ static inline bool qIsNull(float f)
#ifdef Q_FULL_TEMPLATE_INSTANTIATION
# define Q_DUMMY_COMPARISON_OPERATOR(C) \
bool operator==(const C&) const { \
- qWarning(#C"::operator==(const "#C"&) was called"); \
+ tqWarning(#C"::operator==(const "#C"&) was called"); \
return false; \
}
#else
@@ -2403,15 +2403,15 @@ Q_CORE_EXPORT int qrand();
#ifndef QT_PRODUCT_LICENSE
# define QT_PRODUCT_LICENSE QLibraryInfo::licensedProducts()
#endif
-QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPath();
-QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathDocs();
-QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathHeaders();
-QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathLibs();
-QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathBins();
-QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathPlugins();
-QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathData();
-QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathTranslations();
-QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathSysconf();
+QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPath();
+QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathDocs();
+QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathHeaders();
+QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathLibs();
+QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathBins();
+QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathPlugins();
+QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathData();
+QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathTranslations();
+QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathSysconf();
#endif
#if defined(Q_OS_SYMBIAN)
@@ -488,7 +488,7 @@ namespace QT_NAMESPACE {}
# define Q_NO_TEMPLATE_FRIENDS
# endif
-/* Apple's GCC 3.1 chokes on our streaming qDebug() */
+/* Apple's GCC 3.1 chokes on our streaming tqDebug() */
# if defined(Q_OS_DARWIN) && __GNUC__ == 3 && (__GNUC_MINOR__ >= 1 && __GNUC_MINOR__ < 3)
# define Q_BROKEN_DEBUG_STREAM